@@ -1,9 +1,12 @@
-from PyQt5 import QtGui, QtCore
-import pyqtgraph as pg
-import numpy as np
-from matplotlib.colors import hsv_to_rgb
 import matplotlib.cm
-from . import classgui, io
+import numpy as np
+import pyqtgraph as pg
+from PyQt5 import QtGui, QtCore
+from matplotlib.colors import hsv_to_rgb
+
+import suite2p.gui.merge
+from . import io
+
 
 def make_buttons(parent, b0):
     """ color buttons at row b0 """
@@ -65,7 +68,7 @@ def make_buttons(parent, b0):
     parent.probedit.setFixedWidth(iwid)
     parent.probedit.setAlignment(QtCore.Qt.AlignRight)
     parent.probedit.returnPressed.connect(
-        lambda: classgui.apply(parent)
+        lambda: suite2p.gui.merge.apply(parent)
     )
     parent.l0.addWidget(parent.probedit, nv + b - 3, 1, 1, 1)
 
@@ -400,17 +403,6 @@ def corr_masks(parent):
 
     rgb_masks(parent, col, c)
 
-def class_masks(parent):
-    c = 6
-    istat = parent.probcell
-    parent.colors['colorbar'][c] = [istat.min(), (istat.max()-istat.min())/2, istat.max()]
-    istat = istat - istat.min()
-    istat = istat / istat.max()
-    col = istat_transform(istat, parent.ops_plot['colormap'])
-    parent.colors['cols'][c] = col
-    parent.colors['istat'][c] = istat.flatten()
-
-    rgb_masks(parent, col, c)
 
 def flip_for_class(parent, iscell):
     ncells = iscell.size
