@@ -1,9 +1,15 @@
+import math
+import warnings
+
 import numpy as np
+from numba import vectorize, float32, int32, njit, prange
 from numpy import fft
 from scipy.fftpack import next_fast_len
-from numba import vectorize,float32,int32,int16,jit,njit,prange, complex64
-import math
-from mkl_fft import fft2, ifft2
+
+try:
+    from mkl_fft import fft2, ifft2
+except ModuleNotFoundError:
+    warnings.warn("mkl_fft not installed.  Install it with conda: conda install mkl_fft", ImportWarning)
 from . import utils
 
 sigL = 0.85 # smoothing width for up-sampling kernels, keep it between 0.5 and 1.0...
@@ -166,10 +172,10 @@ def phasecorr_reference(refImg1, ops):
         cfRefImg1[n,0,:,:] = (cfRefImg.astype('complex64'))
     return maskMul1, maskOffset1, cfRefImg1
 
-@vectorize([float32(float32, float32, float32)], nopython=True, target = 'parallel')
+@vectorize([float32(float32, float32, float32)], nopython=True, target = 'parallel', cache=True)
 def apply_masks(Y, maskMul, maskOffset):
     return Y*maskMul + maskOffset
-@vectorize(['complex64(int16, float32, float32)', 'complex64(float32, float32, float32)'], nopython=True, target = 'parallel')
+@vectorize(['complex64(int16, float32, float32)', 'complex64(float32, float32, float32)'], nopython=True, target = 'parallel', cache=True)
 def addmultiply(x,y,z):
     return np.complex64(x*y + z)
 
@@ -337,7 +343,7 @@ def linear_interp(iy, ix, yb, xb, f):
     return fup
 
 @njit(['(int16[:, :],float32[:,:], float32[:,:], float32[:,:])', 
-        '(float32[:, :],float32[:,:], float32[:,:], float32[:,:])'])
+        '(float32[:, :],float32[:,:], float32[:,:], float32[:,:])'], cache=True)
 def map_coordinates(I, yc, xc, Y):
     """ bilinear transform of image with ycoordinates yc and xcoordinates xc to Y 
     
@@ -379,12 +385,12 @@ def map_coordinates(I, yc, xc, Y):
                       np.float32(I[yf1, xf]) * y * (1 - x) +
                       np.float32(I[yf1, xf1]) * y * x )
 
-@vectorize([int32(float32)], nopython=True)
+@vectorize([int32(float32)], nopython=True, cache=True)
 def nfloor(y):
     return math.floor(y) #np.int32(np.floor(y))
 
 @njit(['int16[:, :,:], float32[:,:,:], float32[:,:,:], float32[:,:], float32[:,:], float32[:,:,:]',
-       'float32[:, :,:], float32[:,:,:], float32[:,:,:], float32[:,:], float32[:,:], float32[:,:,:]'], parallel=True)
+       'float32[:, :,:], float32[:,:,:], float32[:,:,:], float32[:,:], float32[:,:], float32[:,:,:]'], parallel=True, cache=True)
 def shift_coordinates(data, yup, xup, mshy, mshx, Y):
     """ shift data into yup and xup coordinates
 
@@ -416,7 +422,7 @@ def shift_coordinates(data, yup, xup, mshy, mshx, Y):
     for t in prange(data.shape[0]):
         map_coordinates(data[t], mshy+yup[t], mshx+xup[t], Y[t])
 
-@njit((float32[:, :,:], float32[:,:,:], float32[:,:], float32[:,:], float32[:,:,:], float32[:,:,:]), parallel=True)
+@njit((float32[:, :,:], float32[:,:,:], float32[:,:], float32[:,:], float32[:,:,:], float32[:,:,:]), parallel=True, cache=True)
 def block_interp(ymax1, xmax1, mshy, mshx, yup, xup):
     """ interpolate from ymax1 to mshy to create coordinate transforms """
     for t in prange(ymax1.shape[0]):
